8191715: Update documentation pointing to "common" directory
authorihse
Thu, 23 Nov 2017 13:24:40 +0100
changeset 47928 fb62d4519338
parent 47927 a6b2d28c8094
child 47929 df9e7f2df01f
8191715: Update documentation pointing to "common" directory Reviewed-by: erikj
doc/building.html
doc/building.md
make/Init.gmk
make/RunTests.gmk
make/conf/jib-profiles.js
--- a/doc/building.html	Thu Nov 23 15:03:22 2017 +0530
+++ b/doc/building.html	Thu Nov 23 13:24:40 2017 +0100
@@ -871,9 +871,9 @@
 <p>When building for distribution, <code>zipped</code> is a good solution. Binaries built with <code>internal</code> is suitable for use by developers, since they facilitate debugging, but should be stripped before distributed to end users.</p>
 <h3 id="autoconf-details">Autoconf Details</h3>
 <p>The <code>configure</code> script is based on the autoconf framework, but in some details deviate from a normal autoconf <code>configure</code> script.</p>
-<p>The <code>configure</code> script in the top level directory of OpenJDK is just a thin wrapper that calls <code>common/autoconf/configure</code>. This in turn provides functionality that is not easily expressed in the normal Autoconf framework, and then calls into the core of the <code>configure</code> script, which is the <code>common/autoconf/generated-configure.sh</code> file.</p>
+<p>The <code>configure</code> script in the top level directory of OpenJDK is just a thin wrapper that calls <code>make/autoconf/configure</code>. This in turn provides functionality that is not easily expressed in the normal Autoconf framework, and then calls into the core of the <code>configure</code> script, which is the <code>make/autoconf/generated-configure.sh</code> file.</p>
 <p>As the name implies, this file is generated by Autoconf. It is checked in after regeneration, to alleviate the common user to have to install Autoconf.</p>
-<p>The build system will detect if the Autoconf source files have changed, and will trigger a regeneration of <code>common/autoconf/generated-configure.sh</code> if needed. You can also manually request such an update by <code>bash common/autoconf/autogen.sh</code>.</p>
+<p>The build system will detect if the Autoconf source files have changed, and will trigger a regeneration of <code>make/autoconf/generated-configure.sh</code> if needed. You can also manually request such an update by <code>bash make/autoconf/autogen.sh</code>.</p>
 <p>If you make changes to the build system that requires a re-generation, note the following:</p>
 <ul>
 <li><p>You must use <em>exactly</em> version 2.69 of autoconf for your patch to be accepted. This is to avoid spurious changes in the generated file. Note that Ubuntu 16.04 ships a patched version of autoconf which claims to be 2.69, but is not.</p></li>
--- a/doc/building.md	Thu Nov 23 15:03:22 2017 +0530
+++ b/doc/building.md	Thu Nov 23 13:24:40 2017 +0100
@@ -1660,18 +1660,18 @@
 deviate from a normal autoconf `configure` script.
 
 The `configure` script in the top level directory of OpenJDK is just a thin
-wrapper that calls `common/autoconf/configure`. This in turn provides
+wrapper that calls `make/autoconf/configure`. This in turn provides
 functionality that is not easily expressed in the normal Autoconf framework,
 and then calls into the core of the `configure` script, which is the
-`common/autoconf/generated-configure.sh` file.
+`make/autoconf/generated-configure.sh` file.
 
 As the name implies, this file is generated by Autoconf. It is checked in after
 regeneration, to alleviate the common user to have to install Autoconf.
 
 The build system will detect if the Autoconf source files have changed, and
-will trigger a regeneration of `common/autoconf/generated-configure.sh` if
+will trigger a regeneration of `make/autoconf/generated-configure.sh` if
 needed. You can also manually request such an update by `bash
-common/autoconf/autogen.sh`.
+make/autoconf/autogen.sh`.
 
 If you make changes to the build system that requires a re-generation, note the
 following:
--- a/make/Init.gmk	Thu Nov 23 15:03:22 2017 +0530
+++ b/make/Init.gmk	Thu Nov 23 13:24:40 2017 +0100
@@ -329,7 +329,7 @@
 	$(call PrintFailureReports)
 	$(call PrintBuildLogFailures)
 	$(call ReportProfileTimes)
-	$(PRINTF) "Hint: See common/doc/building.html#troubleshooting for assistance.\n\n"
+	$(PRINTF) "Hint: See doc/building.html#troubleshooting for assistance.\n\n"
         ifneq ($(COMPARE_BUILD), )
 	  $(call CleanupCompareBuild)
         endif
--- a/make/RunTests.gmk	Thu Nov 23 15:03:22 2017 +0530
+++ b/make/RunTests.gmk	Thu Nov 23 13:24:40 2017 +0100
@@ -162,7 +162,7 @@
 ifeq ($(TEST), )
   $(info No test selection given in TEST!)
   $(info Please use e.g. 'run-test TEST=tier1' or 'run-test-tier1')
-  $(info See common/doc/testing.[md|html] for help)
+  $(info See doc/testing.[md|html] for help)
   $(error Cannot continue)
 endif
 
@@ -185,7 +185,7 @@
 
 ifneq ($(UNKNOWN_TEST), )
   $(info Unknown test selection: '$(UNKNOWN_TEST)')
-  $(info See common/doc/testing.[md|html] for help)
+  $(info See doc/testing.[md|html] for help)
   $(error Cannot continue)
 endif
 
--- a/make/conf/jib-profiles.js	Thu Nov 23 15:03:22 2017 +0530
+++ b/make/conf/jib-profiles.js	Thu Nov 23 13:24:40 2017 +0100
@@ -203,7 +203,7 @@
     data.src_bundle_excludes = "./build webrev* */webrev* */*/webrev* */*/*/webrev* .hg */.hg */*/.hg */*/*/.hg";
     // Include list to use when creating a minimal jib source bundle which
     // contains just the jib configuration files.
-    data.conf_bundle_includes = "*/conf/jib-profiles.* common/autoconf/version-numbers"
+    data.conf_bundle_includes = "*/conf/jib-profiles.* make/autoconf/version-numbers"
 
     // Define some common values
     var common = getJibProfilesCommon(input, data);
@@ -1043,7 +1043,7 @@
 
 /**
  * Constructs the numeric version string from reading the
  * common/autoconf/version-numbers file and removing all trailing ".0".
  *
  * @param major Override major version
  * @param minor Override minor version
@@ -1080,17 +1080,17 @@
     return args;
 }
 
 // Properties representation of the common/autoconf/version-numbers file. Lazily
 // initiated by the function below.
 var version_numbers;
 
 /**
  * Read the common/autoconf/version-numbers file into a Properties object.
  *
  * @returns {java.utilProperties}
  */
 var getVersionNumbers = function () {
     // Read version information from common/autoconf/version-numbers
     if (version_numbers == null) {
         version_numbers = new java.util.Properties();
         var stream = new java.io.FileInputStream(__DIR__ + "/../autoconf/version-numbers");
@@ -1043,7 +1043,7 @@
 /**
  * Constructs the numeric version string from reading the
- * common/autoconf/version-numbers file and removing all trailing ".0".
+ * make/autoconf/version-numbers file and removing all trailing ".0".
  *
  * @param major Override major version
@@ -1080,17 +1080,17 @@
 }
 
-// Properties representation of the common/autoconf/version-numbers file. Lazily
+// Properties representation of the make/autoconf/version-numbers file. Lazily
 // initiated by the function below.
 var version_numbers;
@@ -1080,17 +1080,17 @@
 
 /**
- * Read the common/autoconf/version-numbers file into a Properties object.
+ * Read the make/autoconf/version-numbers file into a Properties object.
  *
  * @returns {java.utilProperties}
@@ -1080,17 +1080,17 @@
  */
 var getVersionNumbers = function () {
-    // Read version information from common/autoconf/version-numbers
+    // Read version information from make/autoconf/version-numbers
     if (version_numbers == null) {
         version_numbers = new java.util.Properties();